summaryrefslogtreecommitdiff
path: root/python
diff options
context:
space:
mode:
authorBrian Potchik <brian@vector35.com>2020-07-04 12:15:33 -0400
committerBrian Potchik <brian@vector35.com>2020-07-04 12:15:33 -0400
commitd34bd65478e02a5dc8d1e2f16f09ce7fcdafcb6d (patch)
treec50a9d74aaad86297c09aa2a8ca982260128a20e /python
parent5409fb4fc1e8727d74448286973243526c948fd3 (diff)
Workspace Settings are now Project Settings.
Diffstat (limited to 'python')
-rw-r--r--python/settings.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/python/settings.py b/python/settings.py
index e8e12fba..0bf0686f 100644
--- a/python/settings.py
+++ b/python/settings.py
@@ -54,8 +54,8 @@ class Settings(object):
================= ========================== ============== ================================ ===============================
Default SettingsDefaultScope Lowest Settings Schema Settings Schema
User SettingsUserScope - <User Directory>/settings.json <TBD>
- Workspace SettingsWorkspaceScope - <TBD> <TBD>
- Context SettingsContextScope Highest BinaryView (Storage in bndb) BinaryView (Storage in bndb)
+ Project SettingsProjectScope - <TBD> <TBD>
+ Resource SettingsResourceScope Highest BinaryView (Storage in BNDB) SettingsResource (Customizable)
================= ========================== ============== ================================ ===============================
Individual settings are identified by a key, which is a string in the form of **'<group>.<name>'**. Groups provide a simple way \
@@ -101,9 +101,9 @@ class Settings(object):
def set_resource_id(self, resource_id = None):
"""
``set_resource_id`` Sets the resource identifier for this class:`Settings` instance. When accessing setting values at the \
- ``SettingsContextScope`` level, the resource identifier is passed along through the backing store interface.
+ ``SettingsResourceScope`` level, the resource identifier is passed along through the backing store interface.
- .. note:: Currently the only available backing store for ``SettingsContextScope`` is a :class:`BinaryView` object. In the context \
+ .. note:: Currently the only available backing store for ``SettingsResourceScope`` is a :class:`BinaryView` object. In the context \
of a :class:`BinaryView` the resource identifier is the :class:`BinaryViewType` name. All settings for this type of backing store \
are saved in the *'Raw'* :class:`BinaryViewType`. This enables the configuration of setting values such that they are available \
during :class:`BinaryView` creation and initialization.